@@ -92,7 +92,7 @@ class Application(ABC):
 
     def init(self, config):
         self.config = config
-        self.app_config = config.get('app')
+        self.app_config = config.get('app', {})
         self.logger = logging.getLogger(self.NAME + 'App')
         self.logger.info('Init application')
 
